# OSE Workbench Core
[![PyPI version](https://badge.fury.io/py/ose-workbench-core.svg)](https://badge.fury.io/py/ose-workbench-core)
[![Conda version](https://anaconda.org/gbroques/ose-workbench-core/badges/version.svg)](https://anaconda.org/gbroques/ose-workbench-core)
[![Build Status](https://travis-ci.org/gbroques/ose-workbench-core.svg?branch=master)](https://travis-ci.org/gbroques/ose-workbench-core)
[![Documentation Status](https://readthedocs.org/projects/ose-workbench-core/badge/?version=latest)](https://ose-workbench-core.readthedocs.io/en/latest/?badge=latest)

Core library common to all [Open Source Ecology (OSE)](https://www.opensourceecology.org/) workbenches.

## Contributing
See [Contributing Guidelines](./CONTRIBUTING.md).

## License
Licensed under the [GNU Lesser General Public License, version 2.1](https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html) or LGPL v2.1. See [LICENSE](./LICENSE) for details.

This is the same license as [FreeCAD](https://wiki.freecadweb.org/Licence) to ensure this code could potentially be incorporated into future FreeCAD modules or FreeCAD source itself.

## Supported FreeCAD Versions
This library supports FreeCAD 18.4.
